import subprocess                                                           
import dbus

def set_wall(picture_file):
    """
    This method sets a wallpaper
    :param picture_file - The file to use for setting the background
    """
    #implementation for desktop envirorments and window mannagers using feh      for 
    #wallpaper management for example: 
    #i3 
    #openbox
    try:
        feh = subprocess.call(["feh", "--bg-fill", picture_file])
    except OSError:
        pass

    #gsettings set org.gnome.desktop.background picture-uri 'file:///home/Jo     hnDoe/Pictures/cool_wallpaper.jpg'
    #implementation for gnome desktops such as:
    #ubuntu
    #gnome
    try:
        command = subprocess.call(["gsettings", "set", "org.gnome.desktop.background", "picture-uri", "file://" + picture_file])
    except OSError:
        pass

    #kde
    try:
        plugin = 'org.kde.image'

        jscript = """
        var allDesktops = desktops();
        print (allDesktops);
        for (i=0;i<allDesktops.length;i++) {
            d = allDesktops[i];
            d.wallpaperPlugin = "%s";
            d.currentConfigGroup = Array("Wallpaper", "%s", "General");
            d.writeConfig("Image", "file://%s")
        }
        """
        bus = dbus.SessionBus()
        plasma = dbus.Interface(bus.get_object('org.kde.plasmashell', '/PlasmaShell'), dbus_interface='org.kde.PlasmaShell')
        plasma.evaluateScript(jscript % (plugin, plugin, picture_file))

    except OSError:
        pass


def get_screen_resolution():
    """
    This method gets the screen resolution using xrandr
    """
    # note, we are using xrandr to get the screen resolution instead of usin     g   
    # something like tkinter or wxpython, which provides a cross platform
    # solution to avoid the need for dependecies.

    #xrandr | grep \* | cut -d' ' -f4

    output = subprocess.Popen("xrandr  | grep \* | cut -d' ' -f4",shell=True     , stdout=subprocess.PIPE).communicate()[0]
    resolution = str(output.split()[0]).replace("b'", '').replace("'", '')
    return resolution



import sys                                                                  
import requests
import tempfile
import os
import configparser
import time 

def get_wall(resolution="1920x1080", search_term=None, output_path=None):
    """
    This method downloads a random  wallpaper to use from unsplash. The file is 
    saved to a temporary file so it can be taken care of by the operating 
    system.

    :param resolution - the resolution to use for retrieving the wallpaper the  
                        default resolution is 1920x1080
    :return - the picture file retrieved
    """

    base_url = 'https://source.unsplash.com/' + resolution +'/?' + search_term

    r = requests.get(base_url)

    fd, picture_file = tempfile.mkstemp(suffix=".jpg", prefix="venus_", dir=output_path)

    with os.fdopen(fd, 'wb') as f:
        #downloading the image to the system
        f.write(r.content)

    return picture_file

def get_config():
    """
    This method gets the configuration for venus

    :return - the config file
    """

    config = configparser.ConfigParser()
    config.read(os.path.join(os.path.expanduser('~'), '.config/venus/config'))

    return config

def main():
    #checking platform for applying the wallpaper
    platform = sys.platform

    #getting config
    config = get_config()
    
    try:
        search_term_config = config['SETTINGS']['SEARCH_TERMS']
        output_path_config = config['SETTINGS']['OUTPUT_PATH']
        wait_time_config = config['SETTINGS']['WAIT_TIME']

    except KeyError: 
        print ('Incorrect config file in $HOME/.config/venus' 
                + '\nPlease make sure all config options are present:'
                + '\nSEARCH_TERMS'
                + '\nOUTPUT_PATH'
                + '\nWAIT_TIME')
        exit()

    #default path for empty OUTPUT_PATH setting
    if not output_path_config:
        output_path_config = None

    #loop control var
    run = True

    while run:

        if 'linux' in platform:
            from venus.os_tools import linux
            linux.set_wall(get_wall(resolution=linux.get_screen_resolution(), 
                search_term=search_term_config,
                output_path = output_path_config))

        elif 'win32' in platform:
            from venus.os_tools import windows 
            windows.set_wall(get_wall(resolution=windows.get_screen_resolution(),
                search_term = search_term_config,
                output_path = output_path_config))

        elif 'darwin' in platform:
            from venus.os_tools import darwin 
            darwin.set_wall(get_wall(resolution=darwin.get_screen_resolution(),
                search_term = search_term_config,
                output_path = output_path_config))

        if not wait_time_config:
            run = False
        else:
            time.sleep(int(wait_time_config))

if __name__ == "__main__":
    main()




import os

__version__ = "0.1.8"

dir_path_to_conf = os.path.join(os.path.expanduser('~'), '.config/venus')

if 'XDG_CONFIG_HOME' in os.environ:
    dir_path_to_conf = os.environ['XDG_CONFIG_HOME']

#setting up config file with setting options
file_path_to_conf = os.path.join(dir_path_to_conf, 'config')
text = """[SETTINGS]
SEARCH_TERMS =
OUTPUT_PATH = 
WAIT_TIME = 
"""

if not os.path.exists(dir_path_to_conf):
    os.makedirs(dir_path_to_conf)

if not os.path.exists(file_path_to_conf):
    with open(file_path_to_conf, 'w') as f:
        f.write(text)



import subprocess                                                           
import ctypes
import os

def set_wall(picture_file):
    """
    This method sets a wallpaper
    :param picture_file - The file to use for setting the background
    """

    #variables for system parameter info for setting the wallaper.

    SPI = 20
    SPIF = 2

    ctypes.windll.user32.SystemParametersInfoW(SPI, 0, picture_file, SPIF)

def get_screen_resolution():
    """
    This method gets the screen resolution using the win32 video controller 
    """
    output = subprocess.Popen("wmic path Win32_VideoController get CurrentHorizontalResolution, CurrentVerticalResolution",shell=True     , stdout=subprocess.PIPE).communicate()[0]

    #cleaning up output 
    resolution = str(output).replace("CurrentHorizontalResolution", "").replace("CurrentVerticalResolution", "").replace("b'", "").replace("\\n" ," ").replace("\\r", " ").split() 

    #formationg resolution
    resolution = resolution[0] + "x" + resolution[1]

    return resolution



from setuptools import setup, find_packages
import os

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='venuspy',
    version='0.1.8',
    author="Alfredo Sequeida",
    description='A cross platform tool for setting a random wallpaper image from unsplash.com',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/AlfredoSequeida/venus',
    download_url='https://github.com/AlfredoSequeida/venus/archive/0.1.8.tar.gz',
    keywords ='wallpaper unsplash randomwallpaper',
    platforms ='any',
    classifiers=[
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Operating System :: Microsoft :: Windows :: Windows 10',
        'Operating System :: Microsoft :: Windows :: Windows 8',
        'Operating System :: Microsoft :: Windows :: Windows 8.1',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX :: Linux',
        'Topic :: Desktop Environment',
        ],
    license='MIT',
    packages=['venus'],
    scripts=[
        'venus/os_tools/linux.py',
        'venus/os_tools/darwin.py',
        'venus/os_tools/windows.py',
        ],
    include_package_data=True,
    install_requires=[
        'requests',
    ],
    entry_points={'console_scripts': ['venus = venus.venus:main']},
)



import subprocess                                                           

def set_wall(picture_file):
    """
    This method sets a wallpaper
    :param picture_file - The file to use for setting the background
    """

    SCRIPT = """/usr/bin/osascript<<END
    tell application "Finder"
    set desktop picture to POSIX file "%s"
    end tell"""

    subprocess.Popen(SCRIPT%picture_file, shell=True)

def get_screen_resolution():
    """
    This method gets the screen resolution using system_profiler
    :return - The screen resolution
    """
    output = subprocess.Popen("system_profiler SPDisplaysDataType |grep Resolution",shell=True     , stdout=subprocess.PIPE).communicate()[0]
    resolution = str(output).replace('Resolution', ' ').replace("\\n'", "").replace(":", "").replace("b'", "").split();
    return resolution[0] + resolution[1] + resolution [2]
